from comp_lead.leaders import lead
from comp_lead.companies import comp
   
# Create an object and call it
obj = lead() 
obj.displayLead()

# Create an object and call it
com = comp() 
com.displayComp()
